OC.L10N.register(
    "core",
    {
    "Please select a file." : "กรุณาเลือกแฟ้ม",
    "File is too big" : "ไฟล์มีขนาดใหญ่เกินไป",
    "Invalid file provided" : "ระบุไฟล์ไม่ถูกต้อง",
    "No image or file provided" : "ไม่มีรูปภาพหรือไฟล์ที่ระบุ",
    "Unknown filetype" : "ไม่รู้จักชนิดของไฟล์",
    "Invalid image" : "รูปภาพไม่ถูกต้อง",
    "An error occurred. Please contact your admin." : "เกิดข้อผิดพลาด กรุณาติดต่อผู้ดูแลระบบของคุณ",
    "No temporary profile picture available, try again" : "ไม่มีรูปภาพโปรไฟล์ชั่วคราว กรุณาลองใหม่อีกครั้ง",
    "No crop data provided" : "ไม่มีการครอบตัดข้อมูลที่ระบุ",
    "No valid crop data provided" : "ไม่ได้ระบุข้อมูลการครอบตัดที่ถูกต้อง",
    "Crop is not square" : "การครอบตัดไม่เป็นสี่เหลี่ยม",
    "Couldn't reset password because the token is invalid" : "ไม่สามารถตั้งรหัสผ่านใหม่เพราะโทเค็นไม่ถูกต้อง",
    "Couldn't reset password because the token is expired" : "ไม่สามารถตั้งค่ารหัสผ่านเพราะโทเค็นหมดอายุ",
    "Couldn't send reset email. Please make sure your username is correct." : "ไม่สามารถส่งข้อมูลการตั้งค่าไปยังอีเมลของคุณ กรุณาตรวจสอบชื่อผู้ใช้ของคุณให้ถูกต้อง",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "ไม่สามารถส่งการตั้งค่าไปยังอีเมลเพราะไม่มีที่อยู่อีเมลสำหรับผู้ใช้นี้ กรุณาติดต่อผู้ดูแลระบบ",
    "%s password reset" : "%s ตั้งรหัสผ่านใหม่",
    "Couldn't send reset email. Please contact your administrator." : "ไม่สามารถส่งข้อมูลการตั้งค่าไปยังอีเมลของคุณ กรุณาติดต่อผู้ดูแลระบบ",
    "Error loading tags" : "เกิดข้อผิดพลาดขณะโหลดแท็ก",
    "Tag already exists" : "มีแท็กอยู่แล้ว",
    "Error deleting tag(s)" : "เกิดข้อผิดพลาดขณะลบแท็ก",
    "Error tagging" : "เกิดข้อผิดพลาดขณะติดแท็ก",
    "Error untagging" : "เกิดข้อผิดพลาดขณะยกเลิกการติดแท็ก",
    "Error favoriting" : "เกิดข้อผิดพลาดขณะเลือกที่ชื่นชอบ",
    "Error unfavoriting" : "เกิดข้อผิดพลาดขณะยกเลิกการเลือกที่ชื่นชอบ",
    "Couldn't send mail to following users: %s " : "ไม่สามารถส่งอีเมลไปยังผู้ใช้: %s",
    "Preparing update" : "เตรียมอัพเดท",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "เตือนการซ่อมแซม:",
    "Repair error: " : "เกิดข้อผิดพลาดในการซ่อมแซม:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "กรุณาใช้คำสั่งอัพเดทเพราะการอัพเดทอัตโนมัติถูกปิดใช้งานใน config.php",
    "[%d / %d]: Checking table %s" : "[%d / %d]: กำลังตรวจสอบตาราง %s",
    "Turned on maintenance mode" : "เปิดโหมดการบำรุงรักษา",
    "Turned off maintenance mode" : "ปิดโหมดการบำรุงรักษา",
    "Maintenance mode is kept active" : "โหมดการบำรุงรักษาจะถูกเก็บไว้ใช้งาน",
    "Updating database schema" : "กำลังอัพเดทฐานข้อมูล schema",
    "Updated database" : "อัพเดทฐานข้อมูลเรียบร้อยแล้ว",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "กำลังตรวจสอบว่าฐานข้อมูล schema สามารถอัพเดทได้หรือไม่ (นี้อาจใช้เวลานานขึ้นอยู่กับขนาดของฐานข้อมูล)",
    "Checked database schema update" : "Schema อัพเดตของฐานข้อมูลถูกตรวจสอบ",
    "Checking updates of apps" : "กำลังตรวจสอบการอัพเดทแอพพลิเคชัน",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "กำลังตรวจสอบว่าฐานข้อมูลสำหรับ schema สำหรับ %s ว่าสามารถอัพเดทได้หรือไม่ (นี้จะใช้เวลานานขึ้นอยู่กับขนาดของฐานข้อมูล)",
    "Checked database schema update for apps" : "Schema อัพเดตของฐานข้อมูลสำหรับแอพฯ",
    "Updated \"%s\" to %s" : "อัพเดท \"%s\" ไปยัง %s",
    "Set log level to debug" : "ตั้งค่าระดับบันทึกเพื่อแก้ปัญหา",
    "Reset log level" : "ตั้งค่าระดับบันทึกใหม่",
    "Starting code integrity check" : "กำลังเริ่มต้นรหัสตรวจสอบความสมบูรณ์",
    "Finished code integrity check" : "ตรวจสอบความสมบูรณ์ของรหัสเสร็จสิ้น",
    "%s (3rdparty)" : "%s (บุคคลที่ 3)",
    "%s (incompatible)" : "%s (เข้ากันไม่ได้)",
    "Following apps have been disabled: %s" : "แอพฯดังต่อไปนี้ถูกปิดการใช้งาน: %s",
    "Already up to date" : "มีอยู่แล้วถึงวันที่",
    "Sunday" : "วันอาทิตย์",
    "Monday" : "วันจันทร์",
    "Tuesday" : "วันอังคาร",
    "Wednesday" : "วันพุธ",
    "Thursday" : "วันพฤหัสบดี",
    "Friday" : "วันศุกร์",
    "Saturday" : "วันเสาร์",
    "Sun." : "อา.",
    "Mon." : "จ.",
    "Tue." : "อ.",
    "Wed." : "พ.",
    "Thu." : "พฤ.",
    "Fri." : "ศ.",
    "Sat." : "ส.",
    "Su" : "อา",
    "Mo" : "จัน",
    "Tu" : "อัง",
    "We" : "พุธ",
    "Th" : "พฤ",
    "Fr" : "ศุก",
    "Sa" : "เสา",
    "January" : "มกราคม",
    "February" : "กุมภาพันธ์",
    "March" : "มีนาคม",
    "April" : "เมษายน",
    "May" : "พฤษภาคม",
    "June" : "มิถุนายน",
    "July" : "กรกฏาคม",
    "August" : "สิงหาคม",
    "September" : "กันยายน",
    "October" : "ตุลาคม",
    "November" : "พฤศจิกายน",
    "December" : "ธันวาคม",
    "Jan." : "ม.ค.",
    "Feb." : "ก.พ.",
    "Mar." : "มี.ค.",
    "Apr." : "เม.ย.",
    "May." : "พ.ค.",
    "Jun." : "มิ.ย.",
    "Jul." : "ก.ค.",
    "Aug." : "ส.ค.",
    "Sep." : "ก.ย.",
    "Oct." : "ต.ค.",
    "Nov." : "พ.ย.",
    "Dec." : "ธ.ค.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">มีปัญหาเกี่ยวกับการตรวจสอบความสมบูรณ์ของรหัส รายละเอียดเพิ่มเติม...</a>",
    "Settings" : "ตั้งค่า",
    "Problem loading page, reloading in 5 seconds" : "เกิดปัญหาขณะโหลดหน้าเว็บ จะรีโหลดหน้าเว็บภายใน 5 วินาที",
    "Saving..." : "กำลังบันทึกข้อมูล...",
    "Dismiss" : "ยกเลิก",
    "seconds ago" : "วินาที ก่อนหน้านี้",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "ลิงค์ที่ใช้สำหรับตั้งค่ารหัสผ่านใหม่ ของคุณ ได้ถูกส่งไปยังอีเมลของคุณ หากคุณยังไม่ได้รับอีกเมล ลองไปดูที่โฟลเดอร์ สแปม/ถังขยะ ในอีเมลของคุณ <br>ทั้งนี้หากหาอีเมลไม่พบกรุณาติดต่อผู้ดูแลระบบ",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ไฟล์ของคุณจะถูกเข้ารหัส หากคุณยังไม่ได้เปิดใช้งานรหัสการกู้คืน คุณจะได้รับข้อมูลของคุณกลับมาหลังจากที่รหัสผ่านของคุณถูกรีเซ็ต<br /> หากคุณไม่แน่ใจว่าควรทำอย่างไรโปรดติดต่อผู้ดูแลระบบของคุณก่อนที่คุณจะดำเนินการต่อไป <br /> คุณต้องการดำเนินการต่อ?",
    "I know what I'm doing" : "ฉันรู้ว่าฉันกำลังทำอะไรอยู่",
    "Password can not be changed. Please contact your administrator." : "หากคุณไม่สามารถเปลี่ยนแปลงรหัสผ่าน กรุณาติดต่อผู้ดูแลระบบ",
    "No" : "ไม่ตกลง",
    "Yes" : "ตกลง",
    "Choose" : "เลือก",
    "Error loading file picker template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดไฟล์เทมเพลต: {error}",
    "Ok" : "ตกลง",
    "Error loading message template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดเทมเพลต: {error} ",
    "read-only" : "อ่านอย่างเดียว",
    "_{count} file conflict_::_{count} file conflicts_" : ["ไฟล์มีปัญหา {count} ไฟล์"],
    "One file conflict" : "มีหนึ่งไฟล์ที่มีปัญหา",
    "New Files" : "วางทับไฟล์เดิม",
    "Already existing files" : "เขียนไฟล์ใหม่",
    "Which files do you want to keep?" : "คุณต้องการเก็บไฟล์?",
    "If you select both versions, the copied file will have a number added to its name." : "เลือกวางทับไฟล์เดิมหรือ เขียนไฟล์ใหม่จะเพิ่มตัวเลขไปยังชื่อของมัน",
    "Cancel" : "ยกเลิก",
    "Continue" : "ดำเนินการต่อ",
    "(all selected)" : "(เลือกทั้งหมด)",
    "({count} selected)" : "(เลือกจำนวน {count})",
    "Error loading file exists template" : "เกิดข้อผิดพลาดขณะโหลดไฟล์เทมเพลตที่มีอยู่",
    "Very weak password" : "รหัสผ่านระดับต่ำมาก",
    "Weak password" : "รหัสผ่านระดับต่ำ",
    "So-so password" : "รหัสผ่านระดับปกติ",
    "Good password" : "รหัสผ่านระดับดี",
    "Strong password" : "รหัสผ่านระดับดีมาก",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "เว็บเซิร์ฟเวอร์ของคุณยังไม่ถูกติดตั้งอย่างถูกต้องเพื่ออนุญาตให้ประสานข้อมูลให้ตรงกัน เนื่องจากอินเตอร์เฟซ WebDAV อาจเสียหาย",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "เซิร์ฟเวอร์นี้ไม่มีการเชื่อมต่ออินเทอร์เน็ตซึ่งหมายความว่าบางส่วนของคุณสมบัติ เช่น การจัดเก็บข้อมูลภายนอก การแจ้งเตือนเกี่ยวกับการอัพเดทหรือการติดตั้งแอพพลิเคชันของบุคคลที่สามจะไม่ทำงาน การเข้าถึงไฟล์จากระยะไกลและการส่งอีเมล์แจ้งเตือนอาจจะไม่ทำงาน เราขอแนะนำให้เปิดใช้งานการเชื่อมต่ออินเทอร์เน็ตสำหรับเซิร์ฟเวอร์นี้ถ้าคุณต้องการใช้งานคุณสมบัติทั้งหมด",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "ขณะนี้คุณกำลังใช้ PHP รุ่น {version} เราขอให้คุณอัพเดท <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">เพื่อเหตุผลด้านประสิทธิภาพและความปลอดภัยของ PHP</a>",
    "Error occurred while checking server setup" : "เกิดข้อผิดพลาดขณะที่ทำการตรวจสอบการติดตั้งเซิร์ฟเวอร์",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "ข้อมูลไดเรกทอรีและไฟล์ของคุณอาจจะสามารถเข้าถึงได้จากอินเทอร์เน็ต ขณะที่ htaccess ไฟล์ไม่ทำงาน เราขอแนะนำให้คุณกำหนดค่าเว็บเซิร์ฟเวอร์ของคุณในทางที่ข้อมูลไดเรกทอรีไม่สามารถเข้าถึงได้หรือคุณย้ายข้อมูลไดเรกทอรีไปยังนอกเว็บเซิร์ฟเวอร์หรือเอกสาร",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "\"{header}\" ไม่ได้กำหนดค่าส่วนหัว Http ให้เท่ากับ \"{expected}\" นี่คือระบบการรักษาความปลอดภัยที่มีศักยภาพหรือลดความเสี่ยงที่จะเกิดขึ้นเราขอแนะนำให้ปรับการตั้งค่านี้",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "คุณกำลังเข้าถึงเว็บไซต์นี้ผ่านทาง HTTP เราขอแนะนำให้คุณกำหนดค่าเซิร์ฟเวอร์ของคุณให้ใช้ HTTPS แทนตามที่อธิบายไว้ใน <a href=\"{docUrl}\">เคล็ดลับการรักษาความปลอดภัย</a> ของเรา",
    "Shared" : "แชร์แล้ว",
    "Shared with {recipients}" : "แชร์กับ {recipients}",
    "Error" : "ข้อผิดพลาด",
    "Error while sharing" : "เกิดข้อผิดพลาดขณะกำลังแชร์ข้อมูล",
    "Error while unsharing" : "เกิดข้อผิดพลาดขณะกำลังยกเลิกการแชร์ข้อมูล",
    "Error setting expiration date" : "เกิดข้อผิดพลาดในการตั้งค่าวันที่หมดอายุ",
    "The public link will expire no later than {days} days after it is created" : "ลิงค์สาธารณะจะหมดอายุภายใน {days} วัน หลังจากที่มันถูกสร้างขึ้น",
    "Set expiration date" : "กำหนดวันที่หมดอายุ",
    "Expiration" : "การหมดอายุ",
    "Expiration date" : "วันที่หมดอายุ",
    "Choose a password for the public link" : "เลือกรหัสผ่านสำหรับลิงค์สาธารณะ",
    "Resharing is not allowed" : "ไม่อนุญาตให้แชร์ข้อมูลที่ซ้ำกัน",
    "Share link" : "แชร์ลิงค์",
    "Link" : "ลิงค์",
    "Password protect" : "ป้องกันด้วยรหัสผ่าน",
    "Password" : "รหัสผ่าน",
    "Allow editing" : "อนุญาตให้แก้ไข",
    "Email link to person" : "ส่งลิงก์ให้ทางอีเมล",
    "Send" : "ส่ง",
    "Sending ..." : "กำลังส่ง...",
    "Email sent" : "ส่งอีเมล์แล้ว",
    "Send link via email" : "ส่งลิงก์ผ่านทางอีเมล",
    "Shared with you and the group {group} by {owner}" : "ได้แชร์ให้กับคุณ และกลุ่ม {group} โดย {owner}",
    "Shared with you by {owner}" : "ถูกแชร์ให้กับคุณโดย {owner}",
    "group" : "กลุ่มผู้ใช้งาน",
    "remote" : "รีโมท",
    "notify by email" : "แจ้งเตือนทางอีเมล",
    "Unshare" : "ยกเลิกการแชร์",
    "can share" : "สามารถแชร์ได้",
    "can edit" : "สามารถแก้ไข",
    "create" : "สร้าง",
    "change" : "เปลี่ยนแปลง",
    "delete" : "ลบ",
    "access control" : "ควบคุมการเข้าถึง",
    "Could not unshare" : "ไม่สามารถยกเลิกการแชร์ได้",
    "Share details could not be loaded for this item." : "รายละเอียดการแชร์ไม่สามารถโหลดสำหรับรายการนี้",
    "No users or groups found for {search}" : "ไม่พบผู้ใช้หรือกลุ่มที่มีชื่อว่า {search}",
    "No users found for {search}" : "ไม่พบผู้ใช้ {search}",
    "{sharee} (remote)" : "{sharee} (รีโมท)",
    "Share" : "แชร์",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "แชร์กับคนใน ownClouds อื่นๆ ที่ใช้ไวยากรณ์ username@example.com/owncloud ",
    "Share with users, groups or remote users…" : "แชร์กับผู้ใช้หรือกลุ่มหรือผู้ใช้โดยการรีโมท ...",
    "Share with users or remote users…" : "แชร์กับผู้ใช้หรือผู้ใช้โดยการรีโมท ...",
    "Error removing share" : "พบข้อผิดพลาดในรายการที่แชร์ออก",
    "Warning" : "คำเตือน",
    "Error while sending notification" : "เกิดข้อผิดพลาดขณะกำลังส่งการแจ้งเตือน",
    "Non-existing tag #{tag}" : "ไม่มีแท็กนี้อยู่ #{tag}",
    "invisible" : "จะมองไม่เห็น",
    "({scope})" : "({scope})",
    "Delete" : "ลบ",
    "Rename" : "เปลี่ยนชื่อ",
    "The object type is not specified." : "ชนิดของวัตถุยังไม่ได้รับการระบุ",
    "Enter new" : "ใส่ข้อมูลใหม่",
    "Add" : "เพิ่ม",
    "Edit tags" : "แก้ไขแท็ก",
    "Error loading dialog template: {error}" : "เกิดข้อผิดพลาดขณะโหลดเทมเพลตไดอะล็อก: {error}",
    "No tags selected for deletion." : "ไม่ได้เลือกแท็กที่ต้องการลบ",
    "unknown text" : "ข้อความที่ไม่รู้จัก",
    "Hello world!" : "สวัสดีทุกคน!",
    "sunny" : "แดดมาก",
    "Hello {name}, the weather is {weather}" : "สวัสดี {name} สภาพอากาศวันนี้มี {weather}",
    "Hello {name}" : "สวัสดี {name}",
    "_download %n file_::_download %n files_" : ["ดาวน์โหลด %n ไฟล์"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "กำลังดำเนินการอัพเกรด หากออกจากหน้านี้ ณ เวลานี้อาจเกิดปัญหาในภายหลัง",
    "Updating to {version}" : "กำลังอัพเดทเป็นรุ่น {version}",
    "An error occurred." : "เกิดข้อผิดพลาด",
    "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "การอัพเดทไม่เป็นผลสำเร็จ กรุณาแจ้งปัญหาที่เกิดขึ้นไปยัง <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">คอมมูนิตี้ผู้ใช้งาน ownCloud</a>",
    "The update was successful. There were warnings." : "การอัพเดทสำเร็จ แต่มีคำเตือนอยู่",
    "The update was successful. Redirecting you to ownCloud now." : "การอัพเดทเสร็จเรียบร้อย กำลังเปลี่ยนเส้นทางไปที่ ownCloud อยู่ในขณะนี้",
    "Searching other places" : "กำลังค้นหาสถานที่อื่นๆ",
    "No search results in other folders" : "ไม่พบผลลัพธ์การค้นหาในโฟลเดอร์อื่นๆ",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["ค้นหาพบ {count} ผลลัพธ์ในโฟลเดอร์อื่นๆ"],
    "Personal" : "ส่วนตัว",
    "Users" : "ผู้ใช้งาน",
    "Apps" : "แอปฯ",
    "Admin" : "ผู้ดูแล",
    "Help" : "ช่วยเหลือ",
    "Access forbidden" : "การเข้าถึงถูกหวงห้าม",
    "File not found" : "ไม่พบไฟล์",
    "The specified document has not been found on the server." : "ไม่พบเอกสารที่ระบุบนเซิร์ฟเวอร์",
    "You can click here to return to %s." : "คุณสามารถคลิกที่นี่เพื่อกลับไปยัง %s",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "นี่คุณ,\nอยากให้คุณทราบว่า %s ได้แชร์ %s กับคุณ\nคลิกดูที่นี่: %s\n",
    "The share will expire on %s." : "การแชร์จะหมดอายุในวันที่ %s",
    "Cheers!" : "ไชโย!",
    "Internal Server Error" : "เกิดข้อผิดพลาดภายในเซิร์ฟเวอร์",
    "The server encountered an internal error and was unable to complete your request." : "พบข้อผิดพลาดภายในเซิร์ฟเวอร์และไม่สามารถดำเนินการตามคำขอของคุณ",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "กรุณาติดต่อผู้ดูแลเซิร์ฟเวอร์ถ้าพบข้อผิดพลาดนี้หลายครั้ง กรุณาระบุรายละเอียดทางเทคนิคที่ด้านล่างในรายงานของคุณ",
    "More details can be found in the server log." : "รายละเอียดเพิ่มเติมสามารถดูได้ที่บันทึกของระบบเซิร์ฟเวอร์",
    "Technical details" : "รายละเอียดทางเทคนิค",
    "Remote Address: %s" : "ที่อยู่รีโมท: %s",
    "Request ID: %s" : "คำขอ ID: %s",
    "Type: %s" : "ชนิด: %s",
    "Code: %s" : "โค้ด: %s",
    "Message: %s" : "ข้อความ: %s",
    "File: %s" : "ไฟล์: %s",
    "Line: %s" : "ไลน์: %s",
    "Trace" : "ร่องรอย",
    "Security warning" : "คำเตือนการรักษาความปลอดภัย",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ข้อมูลไดเรกทอรีและไฟล์ของคุณ อาจไม่สามารถเข้าถึงได้จากอินเทอร์เน็ตเพราะ htaccess ไฟล์ไม่ทำงาน",
    "Create an <strong>admin account</strong>" : "สร้าง <strong>บัญชีผู้ดูแลระบบ</strong>",
    "Username" : "ชื่อผู้ใช้งาน",
    "Storage & database" : "พื้นที่จัดเก็บข้อมูลและฐานข้อมูล",
    "Data folder" : "โฟลเดอร์เก็บข้อมูล",
    "Configure the database" : "ตั้งค่าฐานข้อมูล",
    "Only %s is available." : "เฉพาะ %s สามารถใช้ได้",
    "Install and activate additional PHP modules to choose other database types." : "ติดตั้งและเปิดใช้งานโมดูล PHP เพิ่มเติมเพื่อเลือกชนิดฐานข้อมูลอื่นๆ",
    "For more details check out the documentation." : "สำหรับรายละเอียดเพิ่มเติมสามารถตรวจสอบได้ที่ <a href=\"%s\" target=\"_blank\">เอกสาร</a>",
    "Database user" : "ชื่อผู้ใช้งานฐานข้อมูล",
    "Database password" : "รหัสผ่านฐานข้อมูล",
    "Database name" : "ชื่อฐานข้อมูล",
    "Database tablespace" : "พื้นที่ตารางในฐานข้อมูล",
    "Database host" : "Database host",
    "Performance warning" : "คำเตือนเรื่องประสิทธิภาพการทำงาน",
    "SQLite will be used as database." : "SQLite จะถูกใช้เป็นฐานข้อมูล",
    "For larger installations we recommend to choose a different database backend." : "สำหรับการติดตั้งขนาดใหญ่เราขอแนะนำให้เลือกแบ็กเอนด์ฐานข้อมูลที่แตกต่างกัน",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "โดยเฉพาะอย่างยิ่งเมื่อใช้ไคลเอนต์เดสก์ทอปสำหรับการประสานข้อมูลโดย SQLite",
    "Finish setup" : "ติดตั้งเลย",
    "Finishing …" : "เสร็จสิ้น ...",
    "Need help?" : "ต้องการความช่วยเหลือ?",
    "See the documentation" : "ดูได้จากเอกสาร",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "นี่คุณ,<br><br>อยากให้คุณทราบว่า %s ได้แชร์ <strong>%s</strong> กับคุณ <br><a href=\"%s\">คลิกดูที่นี่</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "โปรแกรมนี้ต้องการ JavaScript สำหรับการดำเนินงานที่ถูกต้อง กรุณา {linkstart}เปิดใช้งาน JavaScript{linkend} และโหลดหน้าเว็บ",
    "Log out" : "ออกจากระบบ",
    "Search" : "ค้นหา",
    "Server side authentication failed!" : "การรับรองความถูกต้องจากเซิร์ฟเวอร์ล้มเหลว!",
    "Please contact your administrator." : "กรุณาติดต่อผู้ดูแลระบบ",
    "Please try again or contact your administrator." : "โปรดลองอีกครั้งหรือติดต่อผู้ดูแลระบบ",
    "Log in" : "เข้าสู่ระบบ",
    "Wrong password. Reset it?" : "รหัสผ่านผิด รีเซ็ตรหัสผ่าน?",
    "Wrong password." : "รหัสผ่านผิดพลาด",
    "Stay logged in" : "จดจำฉัน",
    "Alternative Logins" : "ทางเลือกการเข้าสู่ระบบ",
    "Use the following link to reset your password: {link}" : "ใช้ลิงค์ต่อไปนี้เพื่อเปลี่ยนรหัสผ่านของคุณใหม่: {link}",
    "New password" : "รหัสผ่านใหม่",
    "New Password" : "รหัสผ่านใหม่",
    "Reset password" : "เปลี่ยนรหัสผ่านใหม่",
    "This ownCloud instance is currently in single user mode." : "ขณะนี้ ownCloud อยู่ในโหมดผู้ใช้คนเดียว",
    "This means only administrators can use the instance." : "ซึ่งหมายความว่าผู้ดูแลระบบสามารถใช้อินสแตนซ์",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "ติดต่อผู้ดูแลระบบของคุณหากข้อความนี้ยังคงมีอยู่หรือปรากฏโดยไม่คาดคิด",
    "Thank you for your patience." : "ขอบคุณสำหรับความคิดเห็น เราจะนำความคิดเห็นของท่านมาอัพเดทระบบให้ดียิ่งขึ้น",
    "You are accessing the server from an untrusted domain." : "คุณกำลังเข้าถึงเซิร์ฟเวอร์จากโดเมนที่ไม่น่าเชื่อถือ",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "กรุณาติดต่อผู้ดูแลระบบ หากคุณเป็นผู้ดูแลระบบ นี้ตัวอย่างการกำหนดค่า \"trusted_domains\" ใน\nconfig/config.php ตัวอย่างการกำหนดค่ามีอยู่ใน config/config.sample.php",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "ทั้งนี้ขึ้นอยู่กับการกำหนดค่าของคุณ ผู้ดูแลระบบอาจสามารถใช้ปุ่มด้านล่างเพื่อกำหนดให้โดเมนนี้มีความน่าเชื่อถือ",
    "Add \"%s\" as trusted domain" : "ได้เพิ่ม \"%s\" เป็นโดเมนที่เชื่อถือ",
    "App update required" : "จำเป้นต้องอัพเดทแอพฯ",
    "%s will be updated to version %s" : "%s จะถูกอัพเดทเป็นเวอร์ชัน %s",
    "These apps will be updated:" : "แอพพลิเคชันเหล่านี้จะถูกอัพเดท:",
    "These incompatible apps will be disabled:" : "แอพพลิเคชันเหล่านี้เข้ากันไม่ได้จะถูกปิดการใช้งาน:",
    "The theme %s has been disabled." : "ธีม %s จะถูกปิดการใช้งาน:",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "โปรดตรวจสอบฐานข้อมูล การตั้งค่าโฟลเดอร์และโฟลเดอร์ข้อมูลจะถูกสำรองไว้ก่อนดำเนินการ",
    "Start update" : "เริ่มต้นอัพเดท",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "เพื่อหลีกเลี่ยงการหมดเวลากับการติดตั้งขนาดใหญ่ คุณสามารถเรียกใช้คำสั่งต่อไปนี้จากไดเรกทอรีการติดตั้งของคุณ:",
    "This %s instance is currently in maintenance mode, which may take a while." : "%s กำลังอยู่ในโหมดการบำรุงรักษาซึ่งอาจใช้เวลาสักครู่",
    "This page will refresh itself when the %s instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อ %s สามารถใช้ได้อีกครั้ง"
},
"nplurals=1; plural=0;");
